@@ -400,6 +400,7 @@ gtk_menu_tracker_item_action_removed (GtkActionObserver   *observer,
   if (self->action_state != NULL)
     {
       g_variant_unref (self->action_state);
+      self->action_state = NULL;
       g_object_notify_by_pspec (G_OBJECT (self), gtk_menu_tracker_item_pspecs[PROP_ACTION_STATE]);
     }
 
@@ -468,7 +469,17 @@ _gtk_menu_tracker_item_new (GtkActionObservable *observable,
         g_variant_unref (state);
     }
   else
-    self->sensitive = TRUE;
+    {
+      gboolean submenu_enabled;
+      if (g_menu_item_get_attribute (self->item, "submenu-enabled", "b", &submenu_enabled))
+        {
+          self->sensitive = submenu_enabled;
+        }
+      else
+        {
+          self->sensitive = TRUE;
+        }
+    }
 
   return self;
 }
